@@ -19,7 +19,7 @@
  * Portions created by the Initial Developer are Copyright (C) 2008
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s): Carsten Book
+ * Contributor(s): Jesse Ruderman
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,13 +35,12 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-475645-01.js';
+var gTestfile = 'regress-438415-01.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 475645;
-var summary = 'Do not crash @ nanojit::LIns::isop';
-var actual = '';
-var expect = '';
-
+var BUGNUMBER = 438415;
+var summary = 'Do not assert: *vp != JSVAL_HOLE';
+var actual = 'No Crash';
+var expect = 'No Crash';
 
 //-----------------------------------------------------------------------------
 test();
@@ -52,29 +51,8 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
-
-  jit(true);
-
-  linkarr = new Array();
-  picarr = new Array();
-  textarr = new Array();
-  var f=161;
-  var t=27;
-  var pics = "";
-  var links = "";
-  var texts = "";
-  var s = f+t;
-  var d = "1";
-  picarr[2] = "2";
-  for(i=1;i<picarr.length;i++)
-  {
-    if(pics=="") pics = picarr[i];
-    else{
-      if(picarr[i].indexOf("jpg")==-1 && picarr[i].indexOf("JPG")==-1) picarr[i] = d;
-    }
-  }
-
-  jit(false);
+ 
+  [1,,].pop();
 
   reportCompare(expect, actual, summary);
 
