@@ -16,10 +16,10 @@
  *
  * The Initial Developer of the Original Code is
  * Mozilla Foundation.
- * Portions created by the Initial Developer are Copyright (C) 2007
+ * Portions created by the Initial Developer are Copyright (C) 2008
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s): Jesse Ruderman
+ * Contributor(s): Gary Kwong
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,10 +35,10 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-352640-02.js';
+var gTestfile = 'regress-452498-101.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 352640;
-var summary = 'Do not assert: scopeStmt or crash @ js_LexicalLookup';
+var BUGNUMBER = 452498;
+var summary = 'TM: upvar2 regression tests';
 var actual = '';
 var expect = '';
 
@@ -52,15 +52,12 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
- 
-  try
-  {
-    new Function("do { with({}) let x; var b; } while( 1 );");
-  }
-  catch(ex)
-  {
-    print(ex + '');
-  }
+
+// ------- Comment #101 From Gary Kwong [:nth10sd]
+
+  uneval(function(){with({functional: []}){x5, y = this;const y }});
+// Assertion failure: strcmp(rval, with_cookie) == 0, at ../jsopcode.cpp:2567
+
   reportCompare(expect, actual, summary);
 
   exitFunc ('test');
